@@ -26,7 +26,6 @@ def test_info_traits(fake_device: Callable[[Dict[str, Any]], Device]) -> None:
     trait = device.traits["sdm.devices.traits.Info"]
     assert "Device Name" == trait.custom_name
 
-
     assert_diagnostics(
         device.get_diagnostics(),
         {
@@ -43,7 +42,6 @@ def test_info_traits(fake_device: Callable[[Dict[str, Any]], Device]) -> None:
     )
 
 
-
 def test_connectivity_traits(fake_device: Callable[[Dict[str, Any]], Device]) -> None:
     device = fake_device(
         {
@@ -170,7 +168,7 @@ def test_multiple_traits(fake_device: Callable[[Dict[str, Any]], Device]) -> Non
 
 
 def test_info_traits_type_error(
-    fake_device: Callable[[Dict[str, Any]], Device]
+    fake_device: Callable[[Dict[str, Any]], Device],
 ) -> None:
     device = fake_device(
         {
@@ -189,7 +187,7 @@ def test_info_traits_type_error(
 
 
 def test_info_traits_missing_optional_field(
-    fake_device: Callable[[Dict[str, Any]], Device]
+    fake_device: Callable[[Dict[str, Any]], Device],
 ) -> None:
     device = fake_device(
         {
@@ -206,7 +204,7 @@ def test_info_traits_missing_optional_field(
 
 
 def test_connectivity_traits_missing_required_field(
-    fake_device: Callable[[Dict[str, Any]], Device]
+    fake_device: Callable[[Dict[str, Any]], Device],
 ) -> None:
     with pytest.raises(ValueError):
         fake_device(
