@@ -75,16 +75,21 @@ def mock_device_id(
 class MediaRouter:
     """Fixture for serving event media."""
 
-    def __init__(self, app: aiohttp.web.Application, recorder: Recorder) -> None:
+    def __init__(
+        self,
+        app: aiohttp.web.Application,
+        recorder: Recorder,
+        device_handler: DeviceHandler,
+    ) -> None:
         self.app = app
         self.recorder = recorder
+        self.device_handler = device_handler
         self.api_responses: dict[str, list[aiohttp.web.Response]] = {}
         self.image_responses: dict[str, aiohttp.web.Response] = {}
         self.clip_responses: dict[str, aiohttp.web.Response] = {}
         self.token_cnt = -1
         self.app.add_routes(
             [
-                aiohttp.web.post(r"/{device_id:.*}:executeCommand", self.api_handler),
                 aiohttp.web.get(r"/image-url/{device_id:.*}", self.image_token_handler),
                 aiohttp.web.get(
                     r"/clip-url/{device_id:.*}/token/{token:.*}", self.clip_handler
@@ -99,15 +104,16 @@ class MediaRouter:
         # Prepare API to generate image url + token
         if device_id not in self.api_responses:
             self.api_responses[device_id] = []
-        self.api_responses[device_id].append(
-            aiohttp.web.json_response(
+        self.device_handler.add_device_command(
+            device_id,
+            [
                 {
                     "results": {
                         "url": f"image-url/{device_id}",
                         "token": token,
                     },
                 }
-            )
+            ],
         )
         # Prepare image serving
         self.image_responses[token] = aiohttp.web.Response(
@@ -155,9 +161,11 @@ class MediaRouter:
 
 
 @pytest.fixture(name="media_router", autouse=True)
-def mock_media_router(app: aiohttp.web.Application, recorder: Recorder) -> MediaRouter:
+def mock_media_router(
+    app: aiohttp.web.Application, recorder: Recorder, device_handler: DeviceHandler
+) -> MediaRouter:
     """Fixture for preparing API and content serving calls."""
-    return MediaRouter(app, recorder)
+    return MediaRouter(app, recorder, device_handler)
 
 
 @pytest.fixture
@@ -196,7 +204,7 @@ async def mock_device(
 ) -> Device:
     api = await api_client()
     devices = await api.async_get_devices()
-    for device in devices: 
+    for device in devices:
         if device.name == device_id:
             return device
     raise ValueError("Invalid test state, couldn't find device.")
@@ -1448,9 +1456,12 @@ async def test_clip_preview_transcode(
 
         return func
 
-    with patch("google_nest_sdm.transcoder.os.path.exists", new_callable=values), patch(
-        "google_nest_sdm.event_media.InMemoryEventMediaStore.async_load_media",
-        return_value=b"fake-video-thumb-bytes",
+    with (
+        patch("google_nest_sdm.transcoder.os.path.exists", new_callable=values),
+        patch(
+            "google_nest_sdm.event_media.InMemoryEventMediaStore.async_load_media",
+            return_value=b"fake-video-thumb-bytes",
+        ),
     ):
         media = await event_media_manager.get_clip_thumbnail_from_token(
             event.event_token
@@ -1591,11 +1602,12 @@ async def test_event_manager_event_expiration_with_transcode(
             return func
 
         # Cache a clip thumbnail to ensure it is expired later
-        with patch(
-            "google_nest_sdm.transcoder.os.path.exists", new_callable=values
-        ), patch(
-            "google_nest_sdm.event_media.InMemoryEventMediaStore.async_load_media",
-            return_value=b"fake-video-thumb-bytes",
+        with (
+            patch("google_nest_sdm.transcoder.os.path.exists", new_callable=values),
+            patch(
+                "google_nest_sdm.event_media.InMemoryEventMediaStore.async_load_media",
+                return_value=b"fake-video-thumb-bytes",
+            ),
         ):
             media = await event_media_manager.get_clip_thumbnail_from_token(event_token)
             assert media
@@ -1705,7 +1717,6 @@ async def test_unknown_event_type(device: Device) -> None:
     assert event.timestamp.isoformat(timespec="seconds") == "2021-12-23T06:35:36+00:00"
 
 
-
 @pytest.mark.parametrize("device_traits", [IMAGE_DOORBELL_TRAITS])
 async def test_invalid_events_persisted(device: Device) -> None:
     data = {
